package benefactoraddresshandler

import (
	"net/http"

	param "git.gocasts.ir/ebhomengo/niki/param/benefactor/address"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	"github.com/labstack/echo/v4"
)

// DeleteAddress godoc
// @Summary      Delete address by benefactor
// @Description  This endpoint is used to delete an address by benefactor
// @Tags         Address
// @Param        id path int true "Address ID"
// @Success 	 204
// @Failure      400  {string}  "Bad request"
// @Security     AuthBearerBenefactor
// @Router       /address/{id} [delete]
func (h Handler) DeleteAddress(c echo.Context) error {
	var req param.DeleteAddressRequest

	if bErr := echo.PathParamsBinder(c).Uint("id", &req.AddressID).BindError(); bErr != nil {

		return echo.NewHTTPError(http.StatusBadRequest)
	}
	claims := claim.GetClaimsFromEchoContext(c)
	req.BenefactorID = claims.UserID
	if fieldErrors, err := h.addressVld.ValidateDeleteRequest(req); err != nil {
		msg, code := httpmsg.Error(err)

		return c.JSON(code, echo.Map{
			"message": msg,
			"errors":  fieldErrors,
		})
	}
	dErr := h.addressSvc.Delete(c.Request().Context(), req)
	if dErr != nil {
		msg, code := httpmsg.Error(dErr)

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusNoContent, nil)
}
