package benefactorkindboxreqhandler

import (
	param "git.gocasts.ir/ebhomengo/niki/param/benefactor/kind_box_req"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	echo "github.com/labstack/echo/v4"
	"net/http"
)

// Add godoc
// @Summary      Add a new kind box request for a benefactor
// @Tags         KindBoxReq
// @Accept       json
// @Produce      json
// @Param        Request body   param.KindBoxReqAddRequest true "New kind box request details"
// @Success      200  {object}  param.KindBoxReqAddResponse
// @Failure      400  {string}  "Bad request"
// @Security     AuthBearerBenefactor
// @Router       /benefactor/kindboxreqs/ [post].
func (h Handler) Add(c echo.Context) error {
	req := param.KindBoxReqAddRequest{}
	if err := c.Bind(&req); err != nil {
		return c.JSON(http.StatusBadRequest, echo.Map{
			"message": errmsg.ErrBadRequest,
		})
		// TODO: return echo.NewHTTPError(http.StatusBadRequest, errmsg.ErrBadRequest) ؟؟؟
	}
	claims := claim.GetClaimsFromEchoContext(c)
	req.BenefactorID = claims.UserID

	if fieldErrors, err := h.benefactorKindBoxReqVld.ValidateAddRequest(req); err != nil {
		msg, code := httpmsg.Error(err)

		return c.JSON(code, echo.Map{
			"message": msg,
			"errors":  fieldErrors,
		})
	}
	resp, sErr := h.benefactorKindBoxReqSvc.Add(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusCreated, resp)
}
