package adminkindboxreqvalidator

import (
	"errors"
	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box_req"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
	"git.gocasts.ir/ebhomengo/niki/validator"
	validation "github.com/go-ozzo/ozzo-validation/v4"
)

func (v Validator) ValidateGetAll(req param.KindBoxReqGetAllRequest) (map[string]string, error) {
	const op = "adminkindboxreqvalidator.ValidateGetAll"
	validFields := []string{
		"id", "benefactor_id", "sender_agent_id",
		"kind_box_type", "status", "count_requested", "count_accepted",
		"deliver_refer_time_id", "deliver_refer_date",
		"deliver_address_id", "delivered_at",
	}
	if err := validation.ValidateStruct(&req,
		validation.Field(&req.Filter, validation.By(validator.AreFilterFieldsValid(validFields))),
		validation.Field(&req.Sort, validation.By(validator.AreSortFieldsValid(validFields))),
	); err != nil {
		fieldErrors := make(map[string]string)

		var errV validation.Errors
		if errors.As(err, &errV) {
			for key, value := range errV {
				if value != nil {
					fieldErrors[key] = value.Error()
				}
			}
		}

		return fieldErrors, richerror.New(op).
			WithMessage(errmsg.ErrorMsgInvalidInput).
			WithKind(richerror.KindInvalid).
			WithMeta(map[string]interface{}{"req": req}).
			WithErr(err)
	}

	return map[string]string{}, nil
}
