package adminkindboxreqvalidator

import (
	"errors"

	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box_req"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
	validation "github.com/go-ozzo/ozzo-validation/v4"
)

func (v Validator) ValidateUpdateRequest(req param.KindBoxReqUpdateRequest) (map[string]string, error) {
	const op = "adminkindboxreqvalidator.ValidateUpdateRequest"

	if err := validation.ValidateStruct(&req,

		validation.Field(&req.ID,
			validation.Required,
			validation.By(v.doesKindBoxRequestExist),
		),
		validation.Field(&req.CountRequested,
			validation.Required,
			validation.Min(uint(MinKindBoxReq)),
			validation.Max(uint(MaxKindBoxReq)),
		),
		validation.Field(&req.CountAccepted,
			validation.Min(uint(MinKindBoxReq)),
			validation.Max(uint(MaxKindBoxReq)),
			validation.When(req.CountRequested > 0, validation.Max(uint(req.CountRequested))),
			validation.By(v.checkCountAcceptedMustBeLessThanCountRequested(req.ID)),
		),
		validation.Field(&req.KindBoxType,
			validation.Required,
			validation.By(v.doesTypeExist),
		),
		validation.Field(&req.DeliverAddressID,
			validation.Required,
			validation.By(v.doesBenefactorAddressExist(req.ID)),
		),
		validation.Field(&req.DeliverReferDate,
			validation.Required,
			validation.By(v.isDateValid),
		),
		validation.Field(&req.DeliverReferTimeID,
			validation.Required,
			validation.By(v.isReferTimeIDValid),
		),
		validation.Field(&req.SenderAgentID,
			validation.When(req.SenderAgentID > 0, validation.By(v.doesAgentExist)),
		),
	); err != nil {
		fieldErrors := make(map[string]string)

		var errV validation.Errors
		if errors.As(err, &errV) {
			for key, value := range errV {
				if value != nil {
					fieldErrors[key] = value.Error()
				}
			}
		}

		return fieldErrors, richerror.New(op).
			WithMessage(errmsg.ErrorMsgInvalidInput).
			WithKind(richerror.KindInvalid).
			WithMeta(map[string]interface{}{"req": req}).
			WithErr(err)
	}

	return map[string]string{}, nil
}
