package agentkindboxvalidator

import (
	"errors"
	param "git.gocasts.ir/ebhomengo/niki/param/agent/kind_box"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
	"git.gocasts.ir/ebhomengo/niki/validator"
	validation "github.com/go-ozzo/ozzo-validation/v4"
)

func (v Validator) ValidateGetAll(req param.GetAllRequest) (map[string]string, error) {
	const op = "agentkindboxvalidator.ValidateGetAll"
	validFields := []string{
		"id", "kind_box_req_id",
		"benefactor_id", "type", "serial_number",
		"return_refer_time_id", "return_refer_date", "return_address_id",
	}
	if err := validation.ValidateStruct(&req,
		validation.Field(&req.Filter, validation.By(validator.AreFilterFieldsValid(validFields))),
		validation.Field(&req.Sort, validation.By(validator.AreSortFieldsValid(validFields))),
	); err != nil {

		fieldErrors := make(map[string]string)

		var errV validation.Errors
		if errors.As(err, &errV) {
			for key, value := range errV {
				if value != nil {
					fieldErrors[key] = value.Error()
				}
			}
		}

		return fieldErrors, richerror.New(op).
			WithMessage(errmsg.ErrorMsgInvalidInput).
			WithKind(richerror.KindInvalid).
			WithMeta(map[string]interface{}{"req": req}).
			WithErr(err)
	}

	return map[string]string{}, nil
}
